@@ -127,6 +127,8 @@ class Conf():
         cls.passwordexpiredmessage = 'Password expired. Please change it.'
         cls.passwordexpire =  int(settings.get("ppss_auth.password_expire",0)  )
 
+        cls.loginfailthreshold = int(settings.get("ppss_auth.login_fail_threshold",5)  )
+        cls.loginfailinterval = int(settings.get("ppss_auth.login_fail_interval",60)  )
 
         ##template path
         cls.templatepackage =       settings.get("ppss_auth.templatepackage", "ppss_auth")
