@@ -215,6 +215,35 @@ class commonTable():
                 q = q.order_by((getattr(cls,orderby).desc()  ))
         return q.all()
 
+class LoginError():
+    def __init__(self,validlogin,enabled,failcount):
+        self.validlogin = validlogin
+        self.enabled = enabled
+        self.failcount = failcount
+
+    def __bool__(self):
+        #return self.validlogin and self.enabled and self.failcount
+        return self.result() == 1
+    
+    def result(self):
+        return 1 if self.failcount and self.validlogin and self.enabled else 0
+        
+    def blocked(self):
+        return self.failcount is not None and not self.failcount
+
+    def resultreason(self):
+        if self.enabled is None:
+            return "user does not exist"
+        if not self.enabled:
+            return "user disabled"
+        if not self.validlogin:
+            return "invalid password"
+        if not self.failcount:
+            return "too many recent fails"
+        return "Ok"
+
+    def __str__(self):
+        return self.username
 
 class PPSsuser(Base,commonTable):
     __tablename__   = 'ppss_user'
@@ -245,11 +274,21 @@ class PPSsuser(Base,commonTable):
 
     @classmethod
     def checkCryptedLogin(cls,user,password,dbsession):
-        res = dbsession.query(cls).filter(cls.username==user).filter(cls.password==password).filter(cls.enabled==1) \
+        #.filter(cls.password==password).filter(cls.enabled==1)
+        res = dbsession.query(cls).filter(cls.username==user) \
             .options(joinedload('groups')) \
             .options(joinedload('groups.permissions')) \
             .all()
-        return res[0] if len(res)==1 else None
+        if len(res)==1:
+            res = res[0]
+            failcount = dbsession.query(PPSsloginhistory).filter(PPSsloginhistory.user_id == res.id).filter(PPSsloginhistory.result==0).filter(PPSsloginhistory.insertdt > datetime.now()-timedelta(minutes=Conf.loginfailinterval)).count()
+            valid = LoginError(res.password == password, res.enabled == 1,failcount<Conf.loginfailthreshold)
+            #res.password == password and res.enabled == 1
+        else:
+            res = None
+            valid = LoginError(None,None,None)
+        return res,valid
+        #return res[0] if len(res)==1 else None
 
     def passwordExpired(self,now = None):
         if now is None:
@@ -344,6 +383,9 @@ class PPSsloginhistory(Base):
     user_id         = Column(Integer, ForeignKey('ppss_user.id'))
     ipaddress       = Column(Unicode(128))
     insertdt        = Column(DateTime,default=datetime.now)
+    result          = Column(Integer)
+    resultreason    = Column(Unicode(128))
+    username        = Column(Unicode(128))
 
 
 class PPSsgroup(Base,commonTable):
@@ -421,4 +463,8 @@ class DBVersion(Base):
             session.add(DBVersion(modulename=DBVersion.myname,moduleversion=moduldeversion,dbversion="1.0") ) 
         else:
             version.moduleversion = moduldeversion
-            version.dbversion = "1.0"
\ No newline at end of file
+            version.dbversion = "1.0"
+
+
+
+
