@@ -7,7 +7,7 @@ from pyramid.renderers import render_to_response
 
 from ..constants import Conf
 from ..ppss_auth_utils import checkPassword,_,__
-from ..models import PPSsuser,PPSsgroup,PPSspermission,constants
+from ..models import PPSsuser,PPSsgroup,PPSspermission,PPSsloginhistory,constants
 
 from pyramid.view import view_defaults,view_config,forbidden_view_config
 from pyramid.httpexceptions import HTTPFound, HTTPNotFound
@@ -82,14 +82,13 @@ class ACLRoot(object):
 
 
 class ForbiddenRoute():
-    def init(self,request):
+    def __init__(self,request):
         self.request = request
 
-
+    #@view_config(route_name='ppsslogin',request_method="GET",renderer=Conf.logintemplate)
     def login(self):
         authcontroller = AuthController(self.request)
-        return {}
-        #authcontroller.login()
+        return authcontroller.login()
 
 
 @view_defaults(require_csrf=True)
@@ -140,6 +139,19 @@ class AuthController():
             'msg':""
         }
 
+    def logloginattempt(self,user,validity,username):
+        self.request.dbsession.add(
+                PPSsloginhistory(
+                    user_id = user.id if user else None,
+                    ipaddress = self.request.remote_addr,
+                    result = validity.result(),
+                    resultreason = validity.resultreason(),
+                    username = username
+                )
+            )
+        l.info("login attempt for user '{username}' result is '{result}':{enter}".format(username=username,result = validity.resultreason(),enter="OK" if validity else "Denied" ) )
+
+
     @view_config(route_name='ppsslogin',renderer=Conf.logintemplate)
     def login(self):
         r = self.request
@@ -168,28 +180,12 @@ class AuthController():
             superuser = False
             res = None
             l.info("Login attempt: u={username}".format(username=username))
-            if username == Conf.adminname:
-                superuser = True
-                if Conf.adminpass and password == Conf.adminpass:
-                    u = PPSsuser.byField('username',username,r.dbsession)
-                    if u:
-                        res = u[0]
-                    else:
-                        self.retdict["msg"] = __('something went wrong with your login. Please check your informations')
-                        return self.retdict
             if res is None:
-                res = PPSsuser.checkLogin(username,password,r.dbsession)
-            if res:
+                res,valid = PPSsuser.checkLogin(username,password,r.dbsession)
+                self.logloginattempt(res,valid,username)
+            if res and valid:
                 res.getPermissionsMap()
                 self.setPrincipalsInSession(res,superuser,res.passwordExpired())
-                #if superuser:
-                #    l.info("{username} logged in as superuser".format(username=username) )
-                #    r.session['admin'] = True
-                #    r.session['principals'] = ["g:admin","g:sysadmin"]
-                #else:
-                #    l.debug("{username} logged in as normal user".format(username=username) )
-                #    r.session['principals'] = res.getPrincipals(res.passwordExpired()) 
-                #    r.session['admin'] = False
                 r.dbsession.expunge(res)
 
                 ## log the last login
@@ -202,9 +198,13 @@ class AuthController():
                 if res.passwordExpired(): 
                     return HTTPFound(r.route_url("ppss:user:changepassword"))
                 return HTTPFound(postloginpage,headers=headers)
-            self.request.dbsession.query(PPSsuser).filter()
+            #wrong password or disabled user
+            
             l.warn("Login attempt failed for user {user}".format(user=username))
-            msgorig = _('something went wrong with your login. Please check your informations')
+            if valid.blocked():
+                msgorig = _('Your account seems to be temporarly blocked. Please wait before retrying or contact your adminstrator.')
+            else:
+                msgorig = _('something went wrong with your login. Please check your informations')
             msg = r.localizer.translate(msgorig,domain="ppss_auth")
             l.info("message is {} with locale '{}' and domain {}".format(msg,r.localizer.locale_name,msgorig.domain))
             self.retdict.update({'logintpl': Conf.publictemplateinherit ,'msg':msg})
